package com.kgraph.graph.service;

import java.util.List;
import com.kgraph.graph.domain.Subtask;

/**
 * 子任务管理Service接口
 * 
 * @author Allen
 * @date 2023-10-16
 */
public interface ISubtaskService 
{
    /**
     * 查询子任务管理
     * 
     * @param id 子任务管理主键
     * @return 子任务管理
     */
    public Subtask selectSubtaskById(Long id);

    /**
     * 查询子任务管理列表
     * 
     * @param subtask 子任务管理
     * @return 子任务管理集合
     */
    public List<Subtask> selectSubtaskList(Subtask subtask);

    /**
     * 新增子任务管理
     * 
     * @param subtask 子任务管理
     * @return 结果
     */
    public int insertSubtask(Subtask subtask);

    /**
     * 修改子任务管理
     * 
     * @param subtask 子任务管理
     * @return 结果
     */
    public int updateSubtask(Subtask subtask);

    /**
     * 批量删除子任务管理
     * 
     * @param ids 需要删除的子任务管理主键集合
     * @return 结果
     */
    public int deleteSubtaskByIds(Long[] ids);

    /**
     * 删除子任务管理信息
     * 
     * @param id 子任务管理主键
     * @return 结果
     */
    public int deleteSubtaskById(Long id);
}
